/**************************************************************************
Name: usbstructures.h
 
**************************************************************************/

#ifndef USB_STRUCTURES_H
#define USB_STRUCTURES_H

#include "stdafx.h"

/* USB descriptor constants */
#define USBDESCR_HID            0x21
#define USBDESCR_HID_REPORT     0x22
#define USBDESCR_HID_PHYS       0x23

#define USBATTR_BUSPOWER        0x80
#define USBATTR_SELFPOWER       0x40
#define USBATTR_REMOTEWAKE      0x20


/**************************************************************************
USB Descriptors types
**************************************************************************/
enum
{	
  	USBDESCR_DEVICE = 1,
	USBDESCR_CONFIG,
    USBDESCR_STRING,
    USBDESCR_INTERFACE,
    USBDESCR_ENDPOINT,
    USBDESCR_DEVICE_QUALIFIER,
    USBDESCR_OTHER_SPEED_CONFIGURATION,
    USBDESCR_INTERFACE_POWER,
    USBDESCR_OTG,
    USBDESCR_DEBUG,
    USBDESCR_INTERFACE_ASSOCIATION,
};

/**************************************************************************
Device Descriptor type
**************************************************************************/
typedef struct
{
	UCHAR	bLength;
    UCHAR	bDescriptorType;
    UINT	bcdUSB;
    UCHAR	bDeviceClass;
    UCHAR	bDeviceSubClass;
    UCHAR	bDeviceProtocol;
    UCHAR	bMaxPacketSize;
    UINT	idVendor;
    UINT	idProduct;
    UINT	bcdDevice;
    UCHAR	iManufacturer;
    UCHAR	iProduct;
    UCHAR	iSerialNumber;
    UCHAR	bNumConfigurations;

} USB_Device_Descriptor_t;

/**************************************************************************
Configuration Descriptor type
**************************************************************************/
typedef struct
{
    UCHAR	bLength;
    UCHAR	bDescriptorType;
    UINT	wTotalLength;
    UCHAR  	bNumInterfaces;
    UCHAR  	bConfigurationValue;
    UCHAR  	iConfiguration;
    UCHAR  	bmAttributes;
    UCHAR  	bMaxPower;

} USB_Configuration_Descriptor_t;

/**************************************************************************
Interface Descriptor type
**************************************************************************/
typedef struct
{
    UCHAR	bLength;
    UCHAR  	bDescriptorType;
    UCHAR  	bInterfaceNumber;
    UCHAR  	bAlternateSetting;
    UCHAR  	bNumEndpoints;
    UCHAR  	bInterfaceClass;
    UCHAR  	bInterfaceSubClass;
    UCHAR  	bInterfaceProtocol;
    UCHAR  	iInterface;

} USB_Interface_Descriptor_t;

/**************************************************************************
Endpoint Descriptor type
**************************************************************************/
typedef struct
{
    UCHAR  	bLength;
    UCHAR  	bDescriptorType;
    UCHAR	bNumber;
    UCHAR	bAttribute;
    UINT	wPacketSize;
    UCHAR	wPollTime;
} USB_Endpoint_Descriptor_t;

/**************************************************************************
CDC Header Functional Descriptor type
**************************************************************************/
typedef struct
{
    UCHAR  	bLength;
    UCHAR  	bDescriptorType;
    UCHAR	bDescriptorSubType;
    UINT	bcdCDC;

} USB_CDC_Header_Functional_Descriptor_t;

/**************************************************************************
CDC Abstract Control Management Functional Descriptor type
**************************************************************************/
typedef struct
{
    UCHAR  	bLength;
    UCHAR  	bDescriptorType;
    UCHAR	bDescriptorSubType;
    UCHAR	bmCapabilities;

} USB_CDC_Abstract_Control_Management_Descriptor_t;

/**************************************************************************
CDC Union Functional Descriptor type
**************************************************************************/
typedef struct
{
    UCHAR  	bLength;
    UCHAR  	bDescriptorType;
    UCHAR	bDescriptorSubType;
    UCHAR	bMasterInterface;
    UCHAR	bSlaveInterface0;

} USB_CDC_Union_Functional_Descriptor_t;

/**************************************************************************
CDC Call Management Functional Descriptor type
**************************************************************************/
typedef struct
{
    UCHAR  	bLength;
    UCHAR  	bDescriptorType;
    UCHAR	bDescriptorSubType;
    UCHAR	bmCapabilities;
    UCHAR	bDataInterface;

} USB_CDC_Call_Management_Functional_Descriptor_t;

/**************************************************************************
CDC Descriptors Packet for Communication Port Emulation
**************************************************************************/
typedef struct
{	
  	USB_Configuration_Descriptor_t						Configuration;
	USB_Interface_Descriptor_t 							Interface0;
	USB_CDC_Header_Functional_Descriptor_t				Header;
    USB_CDC_Abstract_Control_Management_Descriptor_t	Control;
    USB_CDC_Union_Functional_Descriptor_t				Union;
    USB_CDC_Call_Management_Functional_Descriptor_t		Management;
    USB_Endpoint_Descriptor_t 							In3;
    USB_Interface_Descriptor_t							Interface1;
    USB_Endpoint_Descriptor_t 							Out1;
	USB_Endpoint_Descriptor_t 							In1;

} USB_CDC_CommPort_Descriptors_Packet_t;


#endif /* #ifndef USB_STRUCTURES_H */
